# About Us

We are the Intelligent Systems Group (ISG) at the University of Siegen in Germany, and we developed and maintain OmniRec in collaboration with our colleagues from the University of Göttingen.

Led by Prof. Dr. Joeran Beel, our group focuses on research in Recommender Systems, Information Retrieval, and Auto-ML. We created OmniRec out of our own need for a robust, standardized experimentation tool, and its earlier versions have served as the basis for many of our research publications.

To learn more about our group and our work, please visit our website: <a href="https://isg.beel.org/">isg.beel.org</a>.